#
# spec file for package libratbag
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019 Matthias Bach <marix@marix.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libratbag
Version:        0.17
Release:        bp156.3.4
Summary:        Configuration library for gaming mice
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/libratbag/libratbag
Source0:        %{name}-%{version}.tar.xz
Source1:        README.SUSE
Patch1:         shebang-env.diff
Patch2:         install-daemon-into-sbindir.patch
Patch3:         harden_ratbagd.service.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  json-glib-devel
BuildRequires:  libunistring-devel
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  python3-evdev
BuildRequires:  python3-gobject
BuildRequires:  swig
BuildRequires:  valgrind
BuildRequires:  pkgconfig(check) >= 0.9.10
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libsystemd) >= 227
BuildRequires:  pkgconfig(libudev) >= 196
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(systemd)

%description
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

%package -n liblur3
Summary:        Logitech Unifying Receiver configuration library
Group:          System/Libraries

%description -n liblur3
A library to configure and handle the /dev hidraw devices belonging
to the "Unifying" wireless receiver.

%package -n ratbagd
Summary:        Service granting access to the configuration options of gaming mice
Group:          Hardware/Other
Requires(pre):  group(games)
Recommends:     libratbag-tools

%description -n ratbagd
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

This subpackage contains the daemon managing access to the hardware.
It enables any user that is a member of the group "games" to configure
supported mice via ratbagctl or Piper.

%package devel
Summary:        Development files for the libratbag game mouse config library
Group:          Development/Libraries/C and C++
Requires:       liblur3 = %{version}

%description devel
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

This subpackage contains the files needed to build programs with
libratbag.

%package tools
Summary:        Utilities for configuring gaming mice
Group:          Hardware/Other
Requires:       python3-evdev
Requires:       ratbagd

%description tools
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

This subpackage contains the ratbag utilities allowing to inspect and configure
mice.

%prep
%autosetup -p1
cp %{SOURCE1} .

%build
%meson -Ddocumentation=false -Ddbus-group=games \
	--includedir="%{_includedir}/%{name}"
%meson_build

%check
%meson_test

%install
%meson_install
mkdir -p "%{buildroot}/%{_sbindir}"
ln -s service "%{buildroot}/%{_sbindir}/rcratbagd"
chmod -x "%{buildroot}/%{_datadir}/%{name}/logitech-g402.device"  # Fix this file for some reaseon being executable
%fdupes %{buildroot}/%{_prefix}

%post   -n liblur3 -p /sbin/ldconfig
%postun -n liblur3 -p /sbin/ldconfig
%pre -n ratbagd
%service_add_pre ratbagd.service

%post -n ratbagd
%service_add_post ratbagd.service

%preun -n ratbagd
%service_del_preun ratbagd.service

%postun -n ratbagd
%service_del_postun ratbagd.service

%files -n liblur3
%{_libdir}/liblur.so.3*

%files devel
%{_libdir}/liblur.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/libratbag/

%files -n ratbagd
%{_sbindir}/ratbagd
%{_sbindir}/rcratbagd
%{_unitdir}/*.service
%{_datadir}/dbus-1/
%{_datadir}/%{name}/
%{_mandir}/man8/*
%doc README.SUSE

%files tools
%{_bindir}/lur-command
%{_bindir}/ratbagctl
%{_mandir}/man1/*

%changelog
* Thu May 11 2023 Matthias Bach <marix@marix.org> - 0.17
- Document the need for users of ratbagd to be a member of the
  group games (bsc#1210669)
  * In description of ratbagd package
  * In the new README.SUSE file of the ratbagd package.
- Switch package to using %%autosetup
* Wed Nov  9 2022 marix@marix.org - 0.17
- Update to version 0.17:
  * Completely new driver for ASUS devices.
  * Sinowealth driver now supports changing report rate, button
    assignments and macros.
  * New compatible devices:
    + ASUS ROG Chakram
    + ASUS ROG GX860 Buzzard Mouse
    + ASUS ROG Gladius II
    + ASUS ROG Gladius II Origin
    + ASUS ROG Gladius II Origin PNK LTD
    + ASUS ROG Keris Wireless
    + ASUS ROG Pugio
    + ASUS ROG Strix Carry
    + ASUS ROG Strix Impact
    + ASUS ROG Strix Impact II Wireless
    + DreamMachines DM5 Blink
    + G-Wolves Hati HT-M Wired
    + Genesys Xenon 770
    + Glorious Model O (with older firmware)
    + Logitech G502 X
    + Logitech G502 X Wireless
    + Logitech G635
    + Logitech G733
    + Logitech MX Anywhere 3B
    + Machenike M620
    + Marvo Scorpion G961
    + More SteelSeries Rival variations
    + Roccat Kone EMP
    + SteelSeries Rival 100/105
  * Report rate changing now works on older SteelSeries mice.
  * Fix multiple configurable devices being shown for one
    connected SteelSeries mouse.
  * Fix setting onboard profile mode in HID++2.0 driver.
  * Fix active resolution slot reading and writing in Sinowealth driver.
  * Fix report rates which are not multiples of 100 not applying.
- Require Meson >= 0.50.0 for build
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_ratbagd.service.patch
* Thu Jun 24 2021 marix@marix.org - 0.16
- Update to version 0.16:
  * Events are now scheduled as soon as possible
  * Improvements to the sinowealth driver
  * Added support for a few devices:
    + Logitech G915 TKL
    + Logitech G Pro X Wireless (only via USB connection)
    + Logitech M545
    + Logitech M500s
    + SteelSeries Kinzu V2 Pro Edition
    + Roccat Kone Pure SEL
    + openinput devices
* Thu Dec 24 2020 Matthias Bach <marix@marix.org> - 0.15
- Make package conform to spec-cleaner
* Sat Sep 26 2020 marix@marix.org
- Update to version 0.15:
  * Added or improved devices:
    + Logitech G5
    + Logitech G203
    + Logitech G300
    + Logitech G9x
    + Logitech MX Vertical
    + Nubwo X7 Spectrum
    + Roccat Kone Pure
    + Sinowealth
* Sun May 24 2020 marix@marix.org
- Update to version 0.14:
  * A few bugfixes and some improvements in the log messages.
  * Added and improved devices:
    + Logitech G305
    + Logitech G402
    + Logitech G935
    + Logitech M720
    + Logitech MX Anywhere 2
* Sat Feb 15 2020 marix@marix.org
- Update to version 0.13:
  * Fixed bug that was preventing users from changing the settings
    of  devices from Logitech's productivity line.
  * Give a more specific error message if user cannot reach ratbagd
    via D-BUS [boo#1150413]
  * Added support for keyboards:
    + Logitech G513
    + Logitech G815
    + Logitech G910
    + Logitech G915
  * Other added and improved devices:
    + Logitech G Powerplay
    + Logitech M590
- Updated shebang-env.diff to properly apply to the new version.
* Mon Dec 30 2019 marix@marix.org
- Update to version 0.12:
  * Logitech devices now work when connected via Bluetooh
  * Default verbosity level changed to raw
  * Added and improved devices:
    + Roccat Kone Pure
    + Logitech M585/M590
  * Fixed devices:
    + Logitech G305
* Mon Nov 11 2019 marix@marix.org
- Update to version 0.11:
  * Added and improved devices:
    + Logitech MX Master, MX Master 3, MX Master AMZ
    + Logitech G305
    + Logitech G502 Hero wireless
    + Logitech G602, G604
    + Steelseries Kinzu v3
* Fri Aug  2 2019 marix@marix.org
- Update to version 0.10:
  * Switched back to "normal" version numbering
  * Added APIVersion field to the DBus API
  * Added Devices:
    + Logitech MX Vertical
  * G700s is now handled as G700. This may have side effects and
    will be addressed in future versions.
- Dropped no longer required patch no-git.diff.
- Updated shebang-env.diff.
- Updated install-daemon-into-sbindir.patch.
- Dropped fix-broken-log-invocation.patch which is now fixed
  upstream.
* Wed Jul 31 2019 marix@marix.org
- Update to version 0.9.906:
  * Added Devices:
    + Logitech G403 Wireless
    + Logitech G403 Hero
    + Logitech G703 Hero
    + Logitech G903 Hero
    + Logitech Marathon M705
    + Logitech MX Anyhwere 2S Bluetooth
    + Logitech MX Ergo
    + Logitech MX518
  * Improved Devices:
    + Logitech G Pro
    + Logitech G602
    + Logitech G603
    + Logitech G900
    + Logitech MX Anyhwere 2
  * Renamed Devices
    + Logitech G900 Wireless to Logitech Lightspeed
  * Add battery voltage reporting for newer mice
  * Install the device files in the top-level datadir
- Added fix-broken-log-invocation.patch.
* Sun Mar 31 2019 Matthias Bach <marix@marix.org>
- Dropped the no longer required build requirement python3-lxml.
* Fri Mar 29 2019 Matthias Bach <marix@marix.org>
- Update to version 0.9.905:
  * Added Devices:
    + Logitech G603
  * Breaking changes in DBus API to move it towards a 1.0 release.
  * SVG handling has been dropped.
  * Ratbagctl interface changed:
  * Device IDs or Device name matching is now used instead of
    event nodes. Use `ratbagctl list` to see device IDs and
    names.
  * Device is now taken as the first argument.
  * Ratbagctl is now case sensitive.
* Wed Jan 30 2019 marix@marix.org
- Update to version 0.9.904:
  * Added Devices:
    + Logitech G PowerPlay
    + Logitech G Pro
    + Logitech G402
    + Logitech G502 HERO
    + Logitech MX Anywhere 2
    + Logitech MX Anywhere 2S
    + Logitech MX Master 2S
    + Steelseries Rival 600
  * Improved Devices:
    + All supported Roccat Devices
    + Logitech G102/203
    + Logitech G502
    + Logitech G600
    + Logitech G603
    + Logitech G903
    + Logitech MX Master
  * Improved error messages provided by the command line tools.
* Tue Oct 16 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.903:
  * Adds GetSvgFd() function on D-BUS required by Piper
  * Add a --version commandline argument ratbagd
  * Added support for the Steelseries Sensei Raw
  * Added support for the Logitech G600
  * Added support for the Logitech G302
* Tue Jul 31 2018 marix@marix.org
- Drop rpmlint configuration as the D-Bus service of the package
  has been whitelisted via bsc#1076467.
* Sat Jul 28 2018 marix@marix.org
- Ensure that group games is present.
* Fri Jul 27 2018 marix@marix.org
- Add install-daemon-into-sbindir-patch.patch: Installs ratbagd
  into /usr/sbin as can only be run by root.
* Tue Jul 10 2018 marix@marix.org
- Move the daemon into a separate subpackage as applications like
  piper can use it without having the command line tools installed.
* Thu Jul  5 2018 marix@marix.org
- Run tests as part of package build.
- Fix disabling of documentation build.
* Thu Jul  5 2018 marix@marix.org
- Suppress the suse-dbus-unauthorized-service lintian error for
  easier testing.
* Wed Jul  4 2018 marix@marix.org
- Update to new upstream release 0.9.902:
  * Add Steelserices Sensei 310
- Remove 0001-meson-dbus-support-build-time-option-to-restrict-D-B.patch
  as it was merged upstream.
* Wed Jul  4 2018 marix@marix.org
- Recovered the deleted package from the hardware project.
- Switch to source retrieved via obs_scm.
* Mon Jan 29 2018 jengelh@inai.de
- Update to new upstream release 0.9.901
  * Fixed a stack buffer overflow that was triggerable
    with dbus-send
  * multiple D-Bus calls caused a 3-byte stack overwrite and
    resulted in a segfault
  * ratbagd_button_set_key() D-Bus callback allowed
    another stack buffer overflow
- Remove 0001-meson-fix-default-value-in-meson_options.txt.patch
- Add 0001-meson-dbus-support-build-time-option-to-restrict-D-B.patch
* Sat Nov 11 2017 jengelh@inai.de
- Update to new upstream release 0.9.900
  * libratbag is not a library anymore. Instead, the ratbagd
    project was merged into libratbag and the main way to
    interact with libratbag is now via its DBus interface. This
    is because anything using libratbag needs to run as root to
    have the required permissions. At that point, an abstraction
    daemon is needed anyway to use it from a GUI app.
- Add 0001-meson-fix-default-value-in-meson_options.txt.patch
  to fix an error during configure step.
- Add shebang-env.diff, no-git.diff .
* Thu Jun  8 2017 jengelh@inai.de
- Update to new upstream release 0.9
  * 2 new drivers (G300 and G-Skill)
  * a brand new LED API
  * a new commit API for sending profiles at once, which should
    reduce the communications between the host and the device
  * some shiny new SVGs
  * convert some Logitech devices to the commit API
  * manpage added for lur-command
* Sat Oct 22 2016 jengelh@inai.de
- Update to new upstream release 0.5
  * No changelog was provided
* Fri Jul  1 2016 jengelh@inai.de
- Update to new git snapshot 0.4.g39
  * add support for Logitech G700, and G700 over wireless
  * enable metadata parsing on G500
  * add profile parsing on G9, button definitions and mappings for G9
  * add G502 and G700 svg data
* Thu Nov 12 2015 jengelh@inai.de
- Initial package (version 0~git620) for build.opensuse.org
